@@ -14,6 +14,7 @@ import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_codeguruprofiler
 import aws_cdk.aws_ec2
 import aws_cdk.aws_iam
+import aws_cdk.aws_kms
 import aws_cdk.aws_lambda
 import aws_cdk.aws_logs
 import aws_cdk.aws_sqs
@@ -32,6 +33,9 @@ class EdgeFunction(
     Convenience resource for requesting a Lambda function in the 'us-east-1' region for use with Lambda@Edge.
     Implements several restrictions enforced by Lambda@Edge.
 
+    Note that this construct requires that the 'us-east-1' region has been bootstrapped.
+    See https://docs.aws.amazon.com/cdk/latest/guide/bootstrapping.html or 'cdk bootstrap --help' for options.
+
     :stability: experimental
     :resource: AWS::Lambda::Function
     """
@@ -41,6 +45,7 @@ class EdgeFunction(
         scope: constructs.Construct,
         id: builtins.str,
         *,
+        stack_id: typing.Optional[builtins.str] = None,
         code: aws_cdk.aws_lambda.Code,
         handler: builtins.str,
         runtime: aws_cdk.aws_lambda.Runtime,
@@ -51,6 +56,7 @@ class EdgeFunction(
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
         events: typing.Optional[typing.List[aws_cdk.aws_lambda.IEventSource]] = None,
         filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
         function_name: typing.Optional[builtins.str] = None,
@@ -78,6 +84,7 @@ class EdgeFunction(
         """
         :param scope: -
         :param id: -
+        :param stack_id: (experimental) The stack ID of Lambda@Edge function. Default: - ``edge-lambda-stack-${region}``
         :param code: The source code of your Lambda function. You can point to a file in an Amazon Simple Storage Service (Amazon S3) bucket or specify your source code as inline text.
         :param handler: The name of the method within your code that Lambda calls to execute your function. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-features.html#gettingstarted-features-programmingmodel. Use ``Handler.FROM_IMAGE`` when defining a function from a Docker image. NOTE: If you specify your source code as inline text by specifying the ZipFile property within the Code property, specify index.function_name as the handler.
         :param runtime: The runtime environment for the Lambda function that you are uploading. For valid values, see the Runtime property in the AWS Lambda Developer Guide. Use ``Runtime.FROM_IMAGE`` when when defining a function from a Docker image.
@@ -88,6 +95,7 @@ class EdgeFunction(
         :param dead_letter_queue_enabled: Enabled DLQ. If ``deadLetterQueue`` is undefined, an SQS queue with default options will be defined for your Function. Default: - false unless ``deadLetterQueue`` is set, which implies DLQ is enabled.
         :param description: A description of the function. Default: - No description.
         :param environment: Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
+        :param environment_encryption: The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
         :param events: Event sources for this function. You can also add event sources using ``addEventSource``. Default: - No event sources.
         :param filesystem: The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
@@ -115,6 +123,7 @@ class EdgeFunction(
         :stability: experimental
         """
         props = EdgeFunctionProps(
+            stack_id=stack_id,
             code=code,
             handler=handler,
             runtime=runtime,
@@ -125,6 +134,7 @@ class EdgeFunction(
             dead_letter_queue_enabled=dead_letter_queue_enabled,
             description=description,
             environment=environment,
+            environment_encryption=environment_encryption,
             events=events,
             filesystem=filesystem,
             function_name=function_name,
@@ -686,6 +696,7 @@ class EdgeFunction(
         "dead_letter_queue_enabled": "deadLetterQueueEnabled",
         "description": "description",
         "environment": "environment",
+        "environment_encryption": "environmentEncryption",
         "events": "events",
         "filesystem": "filesystem",
         "function_name": "functionName",
@@ -708,6 +719,7 @@ class EdgeFunction(
         "code": "code",
         "handler": "handler",
         "runtime": "runtime",
+        "stack_id": "stackId",
     },
 )
 class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
@@ -725,6 +737,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
         events: typing.Optional[typing.List[aws_cdk.aws_lambda.IEventSource]] = None,
         filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
         function_name: typing.Optional[builtins.str] = None,
@@ -747,6 +760,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         code: aws_cdk.aws_lambda.Code,
         handler: builtins.str,
         runtime: aws_cdk.aws_lambda.Runtime,
+        stack_id: typing.Optional[builtins.str] = None,
     ) -> None:
         """(experimental) Properties for creating a Lambda@Edge function.
 
@@ -761,6 +775,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         :param dead_letter_queue_enabled: Enabled DLQ. If ``deadLetterQueue`` is undefined, an SQS queue with default options will be defined for your Function. Default: - false unless ``deadLetterQueue`` is set, which implies DLQ is enabled.
         :param description: A description of the function. Default: - No description.
         :param environment: Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
+        :param environment_encryption: The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
         :param events: Event sources for this function. You can also add event sources using ``addEventSource``. Default: - No event sources.
         :param filesystem: The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
@@ -783,6 +798,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         :param code: The source code of your Lambda function. You can point to a file in an Amazon Simple Storage Service (Amazon S3) bucket or specify your source code as inline text.
         :param handler: The name of the method within your code that Lambda calls to execute your function. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-features.html#gettingstarted-features-programmingmodel. Use ``Handler.FROM_IMAGE`` when defining a function from a Docker image. NOTE: If you specify your source code as inline text by specifying the ZipFile property within the Code property, specify index.function_name as the handler.
         :param runtime: The runtime environment for the Lambda function that you are uploading. For valid values, see the Runtime property in the AWS Lambda Developer Guide. Use ``Runtime.FROM_IMAGE`` when when defining a function from a Docker image.
+        :param stack_id: (experimental) The stack ID of Lambda@Edge function. Default: - ``edge-lambda-stack-${region}``
 
         :stability: experimental
         """
@@ -819,6 +835,8 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
             self._values["description"] = description
         if environment is not None:
             self._values["environment"] = environment
+        if environment_encryption is not None:
+            self._values["environment_encryption"] = environment_encryption
         if events is not None:
             self._values["events"] = events
         if filesystem is not None:
@@ -857,6 +875,8 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
             self._values["vpc"] = vpc
         if vpc_subnets is not None:
             self._values["vpc_subnets"] = vpc_subnets
+        if stack_id is not None:
+            self._values["stack_id"] = stack_id
 
     @builtins.property
     def max_event_age(self) -> typing.Optional[aws_cdk.core.Duration]:
@@ -981,6 +1001,15 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         result = self._values.get("environment")
         return result
 
+    @builtins.property
+    def environment_encryption(self) -> typing.Optional[aws_cdk.aws_kms.IKey]:
+        """The AWS KMS key that's used to encrypt your function's environment variables.
+
+        :default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
+        """
+        result = self._values.get("environment_encryption")
+        return result
+
     @builtins.property
     def events(self) -> typing.Optional[typing.List[aws_cdk.aws_lambda.IEventSource]]:
         """Event sources for this function.
@@ -1270,6 +1299,17 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         assert result is not None, "Required property 'runtime' is missing"
         return result
 
+    @builtins.property
+    def stack_id(self) -> typing.Optional[builtins.str]:
+        """(experimental) The stack ID of Lambda@Edge function.
+
+        :default: - ``edge-lambda-stack-${region}``
+
+        :stability: experimental
+        """
+        result = self._values.get("stack_id")
+        return result
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
